# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_list_chat_message_read_with_metadata import ResponseWrapperListChatMessageReadWithMetadata  # noqa: E501

class TestResponseWrapperListChatMessageReadWithMetadata(unittest.TestCase):
    """ResponseWrapperListChatMessageReadWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListChatMessageReadWithMetadata:
        """Test ResponseWrapperListChatMessageReadWithMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListChatMessageReadWithMetadata`
        """
        model = ResponseWrapperListChatMessageReadWithMetadata()  # noqa: E501
        if include_optional:
            return ResponseWrapperListChatMessageReadWithMetadata(
                done = True,
                result = [
                    chat_server_connector.models.chat_message_read_with_metadata.ChatMessageReadWithMetadata(
                        text = '', 
                        file_id = '', 
                        id = 56, 
                        chat_message_type = 'TEXT', 
                        run_id = '', 
                        chat_id = 56, 
                        chat_member_id = 56, 
                        added_at = 56, 
                        attachments = [
                            chat_server_connector.models.chat_message_attachment_read_with_metadata.ChatMessageAttachmentReadWithMetadata(
                                file_id = '', 
                                attachment_type = 'IMAGE', 
                                id = 56, 
                                file_url = '', 
                                full_file_name = '', 
                                file_size = 56, 
                                file_extension = '', 
                                mime_type = '', )
                            ], 
                        chat_session = chat_server_connector.models.chat_session_get.ChatSessionGet(
                            id = 56, 
                            chat_id = 56, 
                            creator_id = 56, 
                            credentials = chat_server_connector.models.credentials.Credentials(), 
                            chat_session_type = 'TEXT', 
                            created_at = 56, 
                            ended_at = 56, 
                            last_activity_at = 56, ), 
                        feedback = chat_server_connector.models.feedback_read.FeedbackRead(
                            id = 56, 
                            chat_session_id = 56, 
                            chat_member_id = 56, 
                            type = 'BUG', 
                            text = '', 
                            priority = 56, 
                            added_at = 56, 
                            updated_at = 56, ), )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListChatMessageReadWithMetadata(
                done = True,
        )
        """

    def testResponseWrapperListChatMessageReadWithMetadata(self):
        """Test ResponseWrapperListChatMessageReadWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
