# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet  # noqa: E501

class TestGoalEngagementPresetGet(unittest.TestCase):
    """GoalEngagementPresetGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoalEngagementPresetGet:
        """Test GoalEngagementPresetGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoalEngagementPresetGet`
        """
        model = GoalEngagementPresetGet()  # noqa: E501
        if include_optional:
            return GoalEngagementPresetGet(
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                order = 56
            )
        else:
            return GoalEngagementPresetGet(
                created_at = 56,
                engagement = 56,
                engagement_opt_out_duration = 56,
                id = 56,
                max_engagement_count = 56,
                max_engagement_period = 56,
                max_total_engagement_count = 56,
                name = '',
                order = 56,
        )
        """

    def testGoalEngagementPresetGet(self):
        """Test GoalEngagementPresetGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
